# libpythonpro
Módulo para exemplificar contrução de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/CursoPythonPro/libpythonpro.svg?branch=master)](https://travis-ci.org/CursoPythonPro/libpythonpro)
[![Updates](https://pyup.io/repos/github/CursoPythonPro/libpythonpro/shield.svg)](https://pyup.io/account/repos/github/CursoPythonPro/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/CursoPythonPro/libpythonpro/python-3-shield.svg)](https://pyup.io/account/repos/github/CursoPythonPro/libpythonpro/)


Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip